==> appstitch_core-0.0.2.tar.gz: lib/core.dart <==
library core;

import 'package:appstitch_core/Config.dart';
import 'package:appstitch_core/constants.dart' as constants;
import 'package:http/http.dart' as http;
import 'package:encrypt/encrypt.dart';
import 'package:crypto/crypto.dart';
import 'dart:convert';
import 'dart:math';

class Core {
  Core._privateConstructor();

  static final Core _instance = Core._privateConstructor();

  factory Core() {
    return _instance;
  }

  Config _config = Config();

  Config config() {
    return _config;
  }

  initialize(Config config) {
    _config = config;
    _config.initialized = true;
    _config.url = constants.url;
  }

  setAuthToken(String token) {
    _config.auth_token = token;
  }

  clearAuthToken() {
    _config = null;
  }

  Future<dynamic> makeRequst(String endpoint, Object payload) async {
    final random = new Random();
    int randomNumber = random.nextInt(10000);

    final url = _config.url + endpoint;

    final key = utf8.encode(_config.appStitchKey);
    final aesKey = Key.fromUtf8(_config.appStitchKey);
    final encrypter = Encrypter(AES(aesKey));

    final pl = json.encode(payload);
    final iv = IV.fromLength(16);
    var body = {
      "payload": encrypter.encrypt(json.encode(payload), iv: iv),
      "auth_token": null
    };

    if (_config.auth_token != null) {
      body["auth_token"] = encrypter.encrypt(_config.auth_token, iv: iv);
    }

    final nonce = randomNumber.toString();

    var headers = {
      "clientID": _config.clientID,
      "authentication": "test",
      "nonce": nonce
    };

    var response = http
        .post(url, headers: headers, body: body)
        .then((result) => json.decode(result.body));
    return response;
  }
}

==> appstitch_core-0.0.4.tar.gz: lib/core.dart <==
library core;

import 'package:appstitch_core/Config.dart';
import 'package:appstitch_core/constants.dart' as constants;
import 'package:http/http.dart' as http;
import 'package:encrypt/encrypt.dart';
import 'package:crypto/crypto.dart';
import 'dart:convert';
import 'dart:math';

class Core {
  Core._privateConstructor();

  static final Core _instance = Core._privateConstructor();

  factory Core() {
    return _instance;
  }

  Config _config = Config();

  Config config() {
    return _config;
  }

  initialize(Config config) {
    _config = config;
    _config.initialized = true;
    _config.url = constants.url;
  }

  setAuthToken(String token) {
    _config.auth_token = token;
  }

  clearAuthToken() {
    _config = null;
  }

  Future<dynamic> makeRequst(String endpoint, Object payload) async {
    final random = new Random();
    int randomNumber = random.nextInt(10000);

    final url = _config.url + endpoint;

    final key = utf8.encode(_config.appStitchKey);
    final aesKey = Key.fromUtf8(_config.appStitchKey);
    final encrypter = Encrypter(AES(aesKey));

    final pl = json.encode(payload);
    final iv = IV.fromLength(16);
    Map<String, String> body = {
      "payload": encrypter.encrypt(json.encode(payload), iv: iv).base64,
      "auth_token": null
    };

    if (_config.auth_token != null) {
      body["auth_token"] = encrypter.encrypt(_config.auth_token, iv: iv).base64;
    }

    final nonce = randomNumber.toString();

    var headers = {
      "clientID": _config.clientID,
      "authentication": "test",
      "nonce": nonce
    };

    var response = http
        .post(url, headers: headers, body: body)
        .then((result) => json.decode(result.body));
    return response;
  }
}
